"""
A library for creating Learning Python Algorithms files.
"""

from .algorithm import AlgorithmDemo
from ._version import get_versions

__version__ = get_versions()['version']
del get_versions

__doc__ = """
chameleon - 这是一个学习 Python 算法 强大工具库
=====================================================================
介绍：
------
1. 可以通过该工具直接学习算法，有相关的算法示例，可以很好的掌握 Python 算法，提高编程逻辑
2. 开发时间：2021-5-20。
3. 版本号：0.1.15。

"""
