import setuptools
setuptools.setup(
    name="testchameleon",
    version="1.0",
    description="this is a module made by kevin",
    author="jiaxing",
    py_modules=["testchameleon._version", "testchameleon.algorithm"]
)
